<?php

/**
 * @file
 *  Contains Drupal\ces\Plugin\Action\CESEdit
 */

namespace Drupal\ces\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;
use Drupal\mcapi\Entity\TransactionInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Action which leads to the entity edit form
 *
 * @Action(
 *   id = "mcapi_transaction.cecsedit_action",
 *   label = @Translation("Edit a transaction (time limited)"),
 *   type = "mcapi_transaction",
 *   confirm_form_route_name = "entity.mcapi_transaction.edit_form"
 * )
 */
class CESEdit extends \Drupal\mcapi\Plugin\Action\Edit{

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $elements = parent::buildConfigurationForm($form, $form_state);

    $elements['period'] = [
      '#title' => t('Period'),
      '#description' => $this->t('Time after creation that transaction can be edited'),
      '#type' => 'select',
      '#options' => [
        '3888000' => $this->t('45 days')
      ]
    ];
    return $elements;
  }

  /**
   * {@inheritdoc}
   *
   * this is only available up to 2 weeks since the transaction was created.
   * @todo make that 2 weeks configurable.
   */

  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    if (!$account) {
      $account = \Drupal::currentUser();
    }
    if ($this->accessState($object, $account)) {
      if ($transaction->created->value + $this->configuration['period'] > REQUEST_TIME) {
        if ($this->accessOp($object, $account)) {
          return $return_as_object ? Access::allowed() : TRUE;
        }
      }
    }
    return $return_as_object ? Access::forbidden() : FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function execute($object = NULL) {

  }


}
