<?php

/**
 * @file
 * Contains \Drupal\hamlets\Plugin\DevelGenerate\HamletsUserGenerate.
 * @see https://www.drupal.org/node/2503429 for possible reason why batching doesn't work
 */

namespace Drupal\hamlets\Plugin\DevelGenerate;

use Drupal\devel_generate\Plugin\DevelGenerate\UserDevelGenerate;
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a UserDevelGenerate plugin.
 *
 * @DevelGenerate(
 *   id = "hamlets_user",
 *   label = @Translation("Users friendly "),
 *   description = @Translation("Generate 26 users with English names. Optionally delete current users."),
 *   url = "user/friendly",
 *   permission = "administer devel_generate",
 *   settings = {
 *     "kill" = FALSE,
 *     "pass" = ""
 *   }
 * )
 */
class HamletsUserGenerate extends UserDevelGenerate {

  private $configFactory;
  private $accountSwitcher;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, $entity_storage, $date_formatter, $config_factory, $account_switcher) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $entity_storage, $date_formatter);
    $this->configFactory = $config_factory;
    $this->accountSwitcher = $account_switcher;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration, $plugin_id, $plugin_definition,
      $container->get('entity.manager')->getStorage('user'),
      $container->get('date.formatter'),
      $container->get('config.factory'),
      $container->get('account_switcher')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);
    $form['num']['#value'] = 26;
    $form['num']['#disabled'] = 26;
    unset($form['roles']);
    unset($form['pass']);
    $form['time_range']['#default_value'] = 31536000;
    $form['time_range']['#type'] = 'hidden';
  }

  /**
   * {@inheritdoc}
   */
  protected function generateElements(array $values) {
    $kill = $values['kill'];
    $pass = $values['pass'];
    $age = $values['time_range'];
    $roles = array_filter($values['roles']);
    $country = strtoupper($this->configFactory->get('system.date')->get('country.default'));

    if ($kill) {
      $uids = $this->userStorage->getQuery()
        ->condition('uid', 1, '>')
        ->execute();
      $users = $this->userStorage->loadMultiple($uids);
      $this->userStorage->delete($users);
    }

    $first = ['Alice', 'Barry', 'Cherry', 'Darius', 'Ebeneezer', 'Fanny', 'Garry', 'Harry', 'Irma', 'Jerry', 'Kerry', 'Larry', 'Murray', 'Nancy', 'Oliver', 'Perry', 'Quentin', 'Ruby', 'Sylvester', 'Terry', 'Ursula', 'Veronica', 'William', 'Xanadu', 'Yuri', 'Zoe'];
    $last = ['Archer', 'Baker', 'Cooper', 'Draper', 'Earl', 'Fisher', 'Gardener', 'Hooper', 'Indignado', 'Joyner', 'Keeler', 'Laker', 'Miller', 'Nutter', 'Oliver', 'Parker', 'Quaker', 'Rider', 'Saddler', 'Turner', 'Usher', 'Vicker', 'Wagner', 'X', 'Yardley', 'Zapatero'];
    shuffle($first);
    shuffle($last);

    if (empty($roles)) {
      $roles = [DRUPAL_AUTHENTICATED_RID];
    }
    //@todo inject this
    //before saving accounts we need to switch to user 1 otherwise the wallet name will be wrongly derived
    $this->accountSwitcher->switchTo(User::load(1));
    for ($i = 0; $i < 26; $i++) {
      $account = $this->userStorage->create([
        'name' => 'a',
        'pass' => 'a',
        'mail' => $first[$i] . '@example.com',
        'init' => $first[$i] . '@example.com',
        'status' => 1,
        'created' => REQUEST_TIME - mt_rand(0, $age),
        'roles' => array_values($roles)
      ]);

      // Populate all fields with sample values.
      $this->populateFields($account);
      //replace the default content with a sensible name
      $account->name->value = $first[$i];
      $account->firstname->value = $first[$i];
      $account->lastname->value = $last[$i];
      $account->address->country_code = $country;
      $account->address->address_line1 = $this->randStreet();
      $account->address->dependent_locality = $this->randNeighbourhood();
      $account->save();
    }
    $this->setMessage('26 users created.');

    $this->accountSwitcher->switchBack();
  }

  function randNeighbourhood() {
    $neighbourhoods = [
      'Apple Green',
      'Black Hills',
      'Cow Common',
      'Ditchwater',
      'Elephantine'
    ];
    return $neighbourhoods[array_rand($neighbourhoods)];
  }

  function randStreet() {
    $streets = [
      'Aberdeen Avenue',
      'Birmingham Boulevard',
      'Dunstable Drive',
      'Harwich Highway',
      'London lane',
      'Paisley Park',
      'Rochester Road',
      'Sheffield Street',
      'Tavistock Track',
      'Warminster Way'
    ];
    return rand(1, 99) .' '. $streets[array_rand($streets)];
  }

}
